# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`st2`](#st2): Base class for st2 module. Used as top-level to set parameters via Hiera, this class does not need to be called directly.
* [`st2::auth`](#st2auth): Class to configure authentication for StackStorm.
* [`st2::auth::common`](#st2authcommon): Class that contains all of the "common" settings for auth.
* [`st2::auth::flat_file`](#st2authflat_file): Auth class to configure and setup Flat File (htpasswd) Authentication
* [`st2::auth::keystone`](#st2authkeystone): Auth class to configure and setup Keystone Based Authentication
* [`st2::auth::ldap`](#st2authldap): Auth class to configure and setup LDAP Based Authentication
* [`st2::auth::mongodb`](#st2authmongodb): Auth class to configure and setup MongoDB Based Authentication
* [`st2::auth::pam`](#st2authpam): Auth class to configure and setup PAM authentication.
* [`st2::kvs`](#st2kvs): Automatically loads Key/Value pairs for StackStorm DB from Hiera
* [`st2::logging::rsyslog`](#st2loggingrsyslog): Helper class to route syslog messages when using rsyslog
* [`st2::notices`](#st2notices): This is a private class used to store long strings to limit down on lint problems.
* [`st2::packs`](#st2packs): Install and configure st2 packages in bulk and via Hiera.
* [`st2::params`](#st2params): Main parameters to manage the st2 module
* [`st2::profile::chatops`](#st2profilechatops): Profile to install and configure chatops for st2
* [`st2::profile::client`](#st2profileclient): Profile to install, configure and manage all client libraries for st2
* [`st2::profile::facter`](#st2profilefacter): Setup custom fact locations
* [`st2::profile::fullinstall`](#st2profilefullinstall): This class performs a full default install of StackStorm and all its components on a single node.
* [`st2::profile::mistral`](#st2profilemistral): This class installs OpenStack Mistral, a workflow engine that integrates with StackStorm.
* [`st2::profile::mongodb`](#st2profilemongodb): StackStorm compatable installation of MongoDB and dependencies.
* [`st2::profile::nginx`](#st2profilenginx): StackStorm compatible installation of nginx and dependencies.
* [`st2::profile::nodejs`](#st2profilenodejs): st2 compatable installation of NodeJS and dependencies for use with StackStorm.
* [`st2::profile::postgresql`](#st2profilepostgresql): st2 compatable installation of PostgreSQL and dependencies for use with StackStorm and Mistral.
* [`st2::profile::python`](#st2profilepython): StackStorm compatable installation of Python and dependencies.
* [`st2::profile::rabbitmq`](#st2profilerabbitmq): StackStorm compatable installation of RabbitMQ and dependencies.
* [`st2::profile::repos`](#st2profilerepos): Manages the installation of st2 required repos for installing the StackStorm packages.
* [`st2::profile::selinux`](#st2profileselinux): Configure SELinux so that StackStorm services run properly
* [`st2::profile::server`](#st2profileserver): Profile to install, configure and manage all server components for st2
* [`st2::profile::web`](#st2profileweb): Profile to install, configure and manage StackStorm web UI (st2web).
* [`st2::scheduler`](#st2scheduler): Manages the <code>st2scheduler</code> service.
* [`st2::server::datastore_keys`](#st2serverdatastore_keys): Generates and manages crypto keys for use with the StackStorm datastore
* [`st2::stanley`](#st2stanley): Installs the default admin user for st2 (stanley).
* [`st2::timersengine`](#st2timersengine): Manages the <code>st2timersengine</code> service.
* [`st2::workflowengine`](#st2workflowengine): Manages the <code>st2workflowengine</code> service (Orquesta)

**Defined types**

* [`st2::auth_user`](#st2auth_user): Creates and manages StackStorm application users (flat_file auth only)
* [`st2::client::settings`](#st2clientsettings): Generates a configuration file for the st2 CLI (st2client)
* [`st2::kv`](#st2kv): Sets a value to the StackStorm Key/Value Store
* [`st2::pack`](#st2pack): Manages a StackStorm Pack
* [`st2::rbac`](#st2rbac): This defined type creates RBAC resources for users
* [`st2::user`](#st2user): Creates an system (OS level) user for use with StackStorm

**Resource types**

* [`st2_pack`](#st2_pack): Manage st2 packs

**Functions**

* [`st2::urlencode`](#st2urlencode): URL encodes a string
* [`st2::version_ge`](#st2version_ge): Determines if the StackStorm version installed or the version requested
by the user is greater than or equal to <code>$version</code>.

## Classes

### st2

Base class for st2 module. Used as top-level to set parameters via Hiera, this class does not need to be called directly.

#### Examples

##### Basic Usage

```puppet
include ::st2
```

##### Variables can be set in Hiera and take advantage of automatic data bindings:

```puppet
st2::version: 2.10.1
```

##### Customizing parameters

```puppet
# best practice is to change default username/password
class { '::st2::params':
  admin_username => 'st2admin',
  admin_password => 'SuperSecret!',
}

class { '::st2':
  version => '2.10.1',
}
```

##### Different passwords for each database (MongoDB, RabbitMQ, Postgres)

```puppet
class { '::st2':
  # StackStorm user
  cli_username        => 'st2admin',
  cli_password        => 'SuperSecret!',
  # MongoDB user for StackStorm
  db_username         => 'admin',
  db_password         => 'KLKfp9#!2',
  # RabbitMQ user for StackStorm
  rabbitmq_username   => 'st2',
  rabbitmq_password   => '@!fsdf0#45',
  # Postrgres user for Mistral
  mistral_db_username => 'stackstorm',
  mistral_db_password => 'FSDfcds#45w',
}
```

#### Parameters

The following parameters are available in the `st2` class.

##### `version`

Data type: `Any`

Version of StackStorm package to install (default = 'present')
See the package 'ensure' property:
https://puppet.com/docs/puppet/5.5/types/package.html#package-attribute-ensure

Default value: 'present'

##### `repository`

Data type: `Any`

Release repository to enable. 'stable', 'unstable'
(default = 'stable')

Default value: $::st2::params::repository

##### `conf_dir`

Data type: `Any`

The directory where st2 configs are stored

Default value: $::st2::params::conf_dir

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: "${::st2::params::conf_dir}/st2.conf"

##### `use_ssl`

Data type: `Any`

Enable/Disable SSL for all st2 APIs

Default value: $::st2::params::use_ssl

##### `ssl_dir`

Data type: `Any`

Directory where st2web will look for its SSL info.
(default: /etc/ssl/st2)

Default value: $::st2::params::ssl_dir

##### `ssl_cert`

Data type: `Any`

Path to the file where the StackStorm SSL cert will
be generated. (default: /etc/ssl/st2/st2.crt)

Default value: $::st2::params::ssl_cert

##### `ssl_key`

Data type: `Any`

Path to the file where the StackStorm SSL key will
be generated. (default: /etc/ssl/st2/st2.key)

Default value: $::st2::params::ssl_key

##### `auth`

Data type: `Any`

Toggle to enable/disable auth (Default: true)

Default value: `true`

##### `auth_api_url`

Data type: `Any`

URL where StackStorm auth service will communicate
with the StackStorm API service

Default value: "http://${::st2::params::hostname}:${::st2::params::api_port}"

##### `auth_debug`

Data type: `Any`

Toggle to enable/disable auth debugging (Default: false)

Default value: `false`

##### `auth_mode`

Data type: `Any`

Auth mode, either 'standalone' or 'backend (default: 'standalone')

Default value: $::st2::params::auth_mode

##### `auth_backend`

Data type: `Any`

Determines which auth backend to configure. (default: flat_file)
Available backends:
- flat_file
- keystone
- ldap
- mongodb
- pam

Default value: $::st2::params::auth_backend

##### `auth_backend_config`

Data type: `Any`

Hash of parameters to pass to the auth backend
class when it's instantiated. This will be different
for every backend. Please see the corresponding
backend class to determine what the config options
should be.

Default value: $::st2::params::auth_backend_config

##### `cli_base_url`

Data type: `Any`

CLI config - Base URL lives

Default value: "http://${::st2::params::hostname}"

##### `cli_api_version`

Data type: `Any`

CLI config - API Version

Default value: 'v1'

##### `cli_debug`

Data type: `Any`

CLI config - Enable/Disable Debug

Default value: `false`

##### `cli_cache_token`

Data type: `Any`

CLI config - True to cache auth token until expries

Default value: `true`

##### `cli_username`

Data type: `Any`

CLI config - Auth Username

Default value: $::st2::params::admin_username

##### `cli_password`

Data type: `Any`

CLI config - Auth Password

Default value: $::st2::params::admin_password

##### `cli_api_url`

Data type: `Any`

CLI config - API URL

Default value: "http://${::st2::params::hostname}:${::st2::params::api_port}"

##### `cli_auth_url`

Data type: `Any`

CLI config - Auth URL

Default value: "http://${::st2::params::hostname}:${::st2::params::auth_port}"

##### `actionrunner_workers`

Data type: `Any`

Set the number of actionrunner processes to start

Default value: $::st2::params::actionrunner_workers

##### `packs`

Data type: `Any`

Hash of st2 packages to be installed

Default value: {}

##### `index_url`

Data type: `Any`

Url to the StackStorm Exchange index file. (default undef)

Default value: `undef`

##### `mistral_db_host`

Data type: `Any`

Hostname/IP of the Mistral Postgres database

Default value: $::st2::params::hostname

##### `mistral_db_name`

Data type: `Any`

Database name of the Mistral Postgres database

Default value: $::st2::params::mistral_db_name

##### `mistral_db_username`

Data type: `Any`

Username for authentication to the Mistral Postgres database

Default value: $::st2::params::mistral_db_username

##### `mistral_db_password`

Data type: `Any`

Password for authentication to the Mistral Postgres database

Default value: $::st2::params::admin_password

##### `mistral_db_bind_ips`

Data type: `Any`

String of IPs (csv) that the Mistral Postgres database
will accept connections on (default: 127.0.0.1)

Default value: $::st2::params::mistral_db_bind_ips

##### `syslog`

Data type: `Any`

Routes all log messages to syslog

Default value: `false`

##### `syslog_host`

Data type: `Any`

Syslog host. Default: localhost

Default value: 'localhost'

##### `syslog_protocol`

Data type: `Any`

Syslog protocol. Default: udp

Default value: 'udp'

##### `syslog_port`

Data type: `Any`

Syslog port. Default: 514

Default value: 514

##### `syslog_facility`

Data type: `Any`

Syslog facility. Default: local7

Default value: 'local7'

##### `ssh_key_location`

Data type: `Any`

Location on filesystem of Admin SSH key for remote runner

Default value: '/home/stanley/.ssh/st2_stanley_key'

##### `db_host`

Data type: `Any`

Hostname to talk to st2 db

Default value: $::st2::params::hostname

##### `db_port`

Data type: `Any`

Port for db server for st2 to talk to

Default value: $::st2::params::mongodb_port

##### `db_bind_ips`

Data type: `Any`

Array of bind IP addresses for MongoDB to listen on

Default value: $::st2::params::mongodb_bind_ips

##### `db_name`

Data type: `Any`

Name of db to connect to (default: 'st2')

Default value: $::st2::params::mongodb_st2_db

##### `db_username`

Data type: `Any`

Username to connect to db with (default: 'stackstorm')

Default value: $::st2::params::mongodb_st2_username

##### `db_password`

Data type: `Any`

Password for 'admin' and 'stackstorm' users in MongDB.
If 'undef' then use $cli_password

Default value: $::st2::params::admin_password

##### `mongodb_version`

Data type: `Any`

Version of MongoDB to install. If not provided it
will be auto-calcuated based on $version
(default: undef)

Default value: `undef`

##### `mongodb_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories
for MongoDB (default: true)

Default value: `true`

##### `mongodb_auth`

Data type: `Any`

Boolean determining if auth should be enabled for
MongoDB. Note: On new versions of Puppet (4.0+)
you'll need to disable this setting.
(default: true)

Default value: `true`

##### `nginx_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories for nginx
(default: true)

Default value: `true`

##### `timersengine_enabled`

Data type: `Any`

Set to true if the st2timersengine service should be enabled
on this node (default: true)

Default value: $::st2::params::timersengine_enabled

##### `timersengine_timezone`

Data type: `Any`

The local timezone for this node. (default: 'America/Los_Angeles')

Default value: $::st2::params::timersengine_timezone

##### `scheduler_sleep_interval`

Data type: `Any`

How long (in seconds) to sleep between each action
scheduler main loop run interval. (default = 0.1)

Default value: $::st2::params::scheduler_sleep_interval

##### `scheduler_gc_interval`

Data type: `Any`

How often (in seconds) to look for zombie execution requests
before rescheduling them. (default = 10)

Default value: $::st2::params::scheduler_gc_interval

##### `scheduler_pool_size`

Data type: `Any`

The size of the pool used by the scheduler for scheduling
executions. (default = 10)

Default value: $::st2::params::scheduler_pool_size

##### `chatops_adapter`

Data type: `Any`

Adapter package(s) to be installed with npm. List of hashes.

Default value: $::st2::params::chatops_adapter

##### `chatops_adapter_conf`

Data type: `Any`

Configuration parameters for Hubot adapter (hash)

Default value: $::st2::params::chatops_adapter_conf

##### `chatops_hubot_log_level`

Data type: `Any`

Logging level for hubot (string)

Default value: $::st2::params::hubot_log_level

##### `chatops_hubot_express_port`

Data type: `Any`

Port that hubot operates on (integer or string)

Default value: $::st2::params::hubot_express_port

##### `chatops_tls_cert_reject_unauthorized`

Data type: `Any`

Should hubot validate SSL certs
Set to 1 when using self signed certs

Default value: $::st2::params::tls_cert_reject_unauthorized

##### `chatops_hubot_name`

Data type: `Any`

Name of the bot in chat. Should be
properly quoted if it has special characters,
example: '"MyBot!"'

Default value: $::st2::params::hubot_name

##### `chatops_hubot_alias`

Data type: `Any`

Character to trigger the bot at the
beginning of a message. Must be properly
quoted of it's a special character,
example: "'!'"

Default value: $::st2::params::hubot_alias

##### `chatops_api_key`

Data type: `Any`

API key generated by `st2 apikey create`
that hubot will use to post data back
to StackStorm.
(default: undef)

Default value: `undef`

##### `chatops_st2_hostname`

Data type: `Any`

Hostname of the StackStorm instance
that chatops will connect to for
API and Auth. If unspecified it will
use the default in /opt/stackstorm/chatops/st2chatops.env
(default: undef)

Default value: $::st2::params::hostname

##### `chatops_api_url`

Data type: `Any`

ChatOps config - API URL

Default value: "https://${::st2::params::hostname}/api"

##### `chatops_auth_url`

Data type: `Any`

ChatOps config - Auth URL

Default value: "https://${::st2::params::hostname}/auth"

##### `chatops_web_url`

Data type: `Any`

Public URL of StackStorm instance.
used by chatops to offer links to
execution details in a chat.
If unspecified it will use the
default in /opt/stackstorm/chatops/st2chatops.env
(default: undef)

Default value: `undef`

##### `nodejs_version`

Data type: `Any`

Version of NodeJS to install. If not provided it
will be auto-calcuated based on $version
(default: undef)

Default value: `undef`

##### `nodejs_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories
for NodeJS (default: true)

Default value: `true`

##### `cli_silence_ssl_warnings`

Data type: `Any`



Default value: `false`

##### `ng_init`

Data type: `Any`



Default value: `true`

##### `datastore_keys_dir`

Data type: `Any`



Default value: $::st2::params::datstore_keys_dir

##### `datastore_key_path`

Data type: `Any`



Default value: "${::st2::params::datstore_keys_dir}/datastore_key.json"

##### `rabbitmq_username`

Data type: `Any`



Default value: $::st2::params::rabbitmq_username

##### `rabbitmq_password`

Data type: `Any`



Default value: $::st2::params::rabbitmq_password

##### `rabbitmq_hostname`

Data type: `Any`



Default value: $::st2::params::rabbitmq_hostname

##### `rabbitmq_port`

Data type: `Any`



Default value: $::st2::params::rabbitmq_port

##### `rabbitmq_bind_ip`

Data type: `Any`



Default value: $::st2::params::rabbitmq_bind_ip

##### `rabbitmq_vhost`

Data type: `Any`



Default value: $::st2::params::rabbitmq_vhost

### st2::auth

StackStorn st2auth service provides a framework for authenticating with
various sources. Plugins to this framework that provide authentication
implementations are called 'backends'. This generic class can be used
to configure the st2auth service and also instantiate a proper backend.
The auth backend implementations are in the manifests/auth/ directory.

#### Examples

##### Basic usage (via ::st2)

```puppet
class { '::st2':
  auth_backend        => 'flat_file',
  auth_backend_config => {
    htpasswd_file => '/etc/something/htpasswd',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "flat_file"
st2::auth_backend_config"
  htpasswd_file: "/etc/something/htpasswd"
```

##### Direct usage (default Flat File auth backend)

```puppet
include ::st2::auth
```

##### Direct usage to configure a specific auth backend

```puppet
class { 'st2::auth':
  backend  => 'mongodb',
  backend_config => {
    db_host => 'mongodb.stackstorm.net',
  }
  use_ssl  => true,
  ssl_cert => '/etc/ssl/cert.crt',
  ssl_key  => '/etc/ssl/cert.key',
}
```

#### Parameters

The following parameters are available in the `st2::auth` class.

##### `backend`

Data type: `Any`

Determines which auth backend to configure. (default: flat_file)
Available backends:
  * flat_file
  * keystone
  * ldap
  * mongodb
  * pam

Default value: $::st2::auth_backend

##### `backend_config`

Data type: `Any`

Hash of parameters to pass to the backend class when it's instantiated.
This will be different for every backend.
Please see the corresponding backend class to determine what the config options should be.

Default value: $::st2::auth_backend_config

##### `debug`

Data type: `Any`

Enable Debug (default: false)

Default value: $::st2::auth_debug

##### `mode`

Data type: `Any`

Authentication mode, either 'standalone' or 'proxy' (default: standalone)

Default value: $::st2::auth_mode

##### `use_ssl`

Data type: `Any`

Enable SSL (default: false)

Default value: $::st2::use_ssl

##### `ssl_cert`

Data type: `Any`

Path to SSL Certificate file (default: '/etc/ssl/st2/st2.crt')

Default value: $::st2::ssl_cert

##### `ssl_key`

Data type: `Any`

Path to SSL Key file (default: '/etc/ssl/st2/st2.key')

Default value: $::st2::ssl_key

### st2::auth::common

Class that contains all of the "common" settings for auth.

* **Note** Don't use directly

#### Parameters

The following parameters are available in the `st2::auth::common` class.

##### `api_url`

Data type: `Any`

URL to the StackStorm API

Default value: $::st2::auth_api_url

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `debug`

Data type: `Any`

Enable Debug (default: false)

Default value: $::st2::auth_debug

##### `mode`

Data type: `Any`

Authentication mode, either 'standalone' or 'proxy' (default: standalone)

Default value: $::st2::auth_mode

##### `use_ssl`

Data type: `Any`

Enable SSL (default: false)

Default value: $::st2::use_ssl

##### `ssl_cert`

Data type: `Any`

Path to SSL Certificate file (default: '/etc/ssl/st2/st2.crt')

Default value: $::st2::ssl_cert

##### `ssl_key`

Data type: `Any`

Path to SSL Key file (default: '/etc/ssl/st2/st2.key')

Default value: $::st2::ssl_key

### st2::auth::flat_file

Auth class to configure and setup Flat File (htpasswd) Authentication

#### Examples

##### Instantiate via ::st2

```puppet
class { '::st2':
  auth_backend        => 'flat_file',
  auth_backend_config => {
    htpasswd_file => '/etc/something/htpasswd',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "flat_file"
st2::auth_backend_config"
  htpasswd_file: "/etc/something/htpasswd"
```

#### Parameters

The following parameters are available in the `st2::auth::flat_file` class.

##### `cli_username`

Data type: `Any`

CLI config - Auth Username

Default value: $::st2::cli_username

##### `cli_password`

Data type: `Any`

CLI config - Auth Password

Default value: $::st2::cli_password

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `htpasswd_file`

Data type: `Any`

Path to htpasswd file (default: /etc/st2/htpasswd)

Default value: $::st2::params::auth_htpasswd_file

### st2::auth::keystone

For information on parameters see the
{backend documentation}[https://github.com/StackStorm/st2-auth-backend-keystone#configuration-options]

#### Examples

##### Instantiate via ::st2

```puppet
class { '::st2':
  auth_backend        => 'keystone',
  auth_backend_config => {
    keystone_url     => 'http://keystone.domain.tld:5000',
    keystone_version => '3',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "keystone"
st2::auth_backend_config:
  keystone_url: "http://keystone.domain.tld:5000"
  keystone_version: "3"
```

#### Parameters

The following parameters are available in the `st2::auth::keystone` class.

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `keystone_url`

Data type: `Any`

Keystone URL to connect to (default: '127.0.0.1')

Default value: 'http://127.0.0.1:5000'

##### `keystone_version`

Data type: `Any`

Keystone API version (default: '2')

Default value: '2'

### st2::auth::ldap

For information on parameters see the
{backend documentation}[https://github.com/StackStorm/st2-auth-backend-ldap#configuration-options]

#### Examples

##### Instantiate via ::st2 (Active Directory)

```puppet
class { '::st2':
  auth_backend        => 'ldap',
  auth_backend_config => {
    ldap_uri      => 'ldaps://ldap.domain.tld',
    bind_dn       => 'cn=ldap_stackstorm,ou=service accounts,dc=domain,dc=tld',
    bind_pw       => 'some_password',
    ref_hop_limit => 100,
    user          => {
      base_dn       => "ou=domain_users,dc=domain,dc=tld",
      search_filter => "(&(objectClass=user)(sAMAccountName={username})(memberOf=cn=stackstorm_users,ou=groups,dc=domain,dc=tld))",
      scope         => "subtree"
    },
  },
}
```

##### Instantiate via Hiera (Active Directory)

```puppet
st2::auth_backend: "ldap"
st2::auth_backend_config:
  ldap_uri: "ldaps://ldap.domain.tld"
  bind_dn: "cn=ldap_stackstorm,ou=service accounts,dc=domain,dc=tld"
  bind_pw: "some_password"
  ref_hop_limit: 100
  user:
    base_dn: "ou=domain_users,dc=domain,dc=tld"
    search_filter: "(&(objectClass=user)(sAMAccountName={username})(memberOf=cn=stackstorm_users,ou=groups,dc=domain,dc=tld))"
    scope: "subtree"
```

#### Parameters

The following parameters are available in the `st2::auth::ldap` class.

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `ldap_uri`

Data type: `Any`

URI of the LDAP server.
Format: <code><protocol>://<hostname>[:port]</code> (protocol: ldap or ldaps)

Default value: ''

##### `use_tls`

Data type: `Any`

Boolean parameter to set if tls is required.
Should be set to false using ldaps in the uri. (default: false)

Default value: `false`

##### `bind_dn`

Data type: `Any`

DN user to bind to LDAP. If an empty string, an anonymous bind is performed.
To use the user supplied username in the bind_dn, use the <code>{username}</code> placeholder
in string.

Default value: ''

##### `bind_pw`

Data type: `Any`

DN password. Use the <code>{password}</code> placeholder in the string to use the user supplied password.

Default value: ''

##### `user`

Data type: `Any`

Search parameters for user authentication

* base_dn - Base DN on the LDAP server to be used when looking up the user account.
* search_filter - LDAP search filter for finding the user in the directory.
  Should contain the placeholder <code>{username}</code> for the username.
* scope - The scope of the search to be performed.
  Available choices: base, onelevel, subtree

Default value: `undef`

##### `group`

Data type: `Any`

Search parameters for user's group membership:

* base_dn - Base DN on the LDAP server to be used when looking up the group.
* search_filter - DAP search filter for finding the group in the directory.
  Should contain the placeholder <code>{username}</code> for the username.
* scope - The scope of the search to be performed.
  Available choices: base, onelevel, subtree

Default value: `undef`

##### `chase_referrals`

Data type: `Any`

Boolean parameter to set whether to chase referrals. (default: true)

Default value: `true`

##### `ref_hop_limit`

Data type: `Any`

The maximum number to refer Referrals recursively (default: 0)

Default value: 0

### st2::auth::mongodb

For information on parameters see the
{backend documentation}[https://github.com/StackStorm/st2-auth-backend-mongodb#configuration-options]

#### Examples

##### Instantiate via ::st2

```puppet
class { '::st2':
  auth_backend        => 'mongodb',
  auth_backend_config => {
    db_host => 'mongodb.stackstorm.net',
    db_port => '1234',
    db_name => 'myauthdb',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "mongodb"
st2::auth_backend_config:
  db_host: "mongodb.stackstorm.net"
  db_port: "1234"
  db_name: "myauthdb"
```

#### Parameters

The following parameters are available in the `st2::auth::mongodb` class.

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `db_host`

Data type: `Any`

Hostname for the MongoDB server (default: 127.0.0.1)

Default value: $::st2::db_host

##### `db_port`

Data type: `Any`

Port for the MongoDB server (default: 27017)

Default value: $::st2::db_port

##### `db_name`

Data type: `Any`

Database name in MongoDB (default: st2auth)

Default value: 'st2auth'

##### `db_auth`

Data type: `Any`

Enable authentication with MongoDB (required for MongoDB installs with auth enabled)

Default value: $::st2::mongodb_auth

##### `db_username`

Data type: `Any`

Username for MongoDB login (default: st2auth)

Default value: $::st2::db_username

##### `db_password`

Data type: `Any`

Password for MongoDB login (default: st2auth)

Default value: $::st2::db_password

### st2::auth::pam

Auth class to configure and setup PAM authentication.

* **TODO** Need to configure st2auth service to run as root

* **Note** This backend will NOT allow you to auth with PAM for the 'root' user.
You will need to auth a non-root user on the Linux host.

#### Examples

##### Instantiate via ::st2

```puppet
class { '::st2':
  backend => 'pam',
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "pam"
st2::auth_backend_config: {}
```

#### Parameters

The following parameters are available in the `st2::auth::pam` class.

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

### st2::kvs

Automatically loads Key/Value pairs for StackStorm DB from Hiera

* **See also**
st2::kv

#### Examples

##### Key/value pairs defined in Hiera

```puppet
st2::kvs:
  keyname:
    value: 'blah'
  mysupercoolkey:
    value: 'xyz123'
```

### st2::logging::rsyslog

This class bootstraps a system configured with rsyslog
and st2::syslog enabled to route messages to all the right
places.

#### Examples

##### Basic usage

```puppet
include ::st2::logging::rsyslog
```

### st2::notices

This is a private class used to store long strings to limit down on lint problems.

* **Note** Please do not call directly

### st2::packs

Install and configure st2 packages in bulk and via Hiera.

* **See also**
st2::pack
and st2::pack::config for usage

#### Examples

##### Basic Usage

```puppet
class { '::st2::packs':
  packs => {
    puppet => {},
    influxdb => {
      config => {
        server => 'influxdb.domain.tld',
    },
  },
}
```

##### Created via Hiera

```puppet
st2::packs:
  puppet: {}
  influxdb:
    config:
      server => 'influxdb.domain.tld'
```

#### Parameters

The following parameters are available in the `st2::packs` class.

##### `packs`

Data type: `Any`



Default value: $::st2::packs

### st2::params

Main parameters to manage the st2 module

#### Examples

##### Best Practice

```puppet
class { '::st2::params':
  admin_username => 'myuser',
  admin_password => 'SuperSecret!',
}
include ::st2::profile::fullinstall
```

#### Parameters

The following parameters are available in the `st2::params` class.

##### `packs_group_name`

Data type: `Any`

The name of the group created to hold the st2 admin user

Default value: 'st2packs'

##### `hostname`

Data type: `Any`

Hostname of the StackStorm box. This is used as the default to drive a lot of
other parameters in the ::st2 class such as auth URL, MongoDB host, RabbitMQ host, etc.

Default value: '127.0.0.1'

##### `admin_username`

Data type: `Any`

Username of the StackStorm admin user. Best practice is to change this to a unique username.

Default value: 'st2admin'

##### `admin_password`

Data type: `Any`

Password of the StackStorm admin user. Best practice is to change this to a unique password.

Default value: 'Ch@ngeMe'

### st2::profile::chatops

Profile to install and configure chatops for st2

* **Note** This class doesn't need to be invoked directly, instead it's best to customize
it through the main +::st2+ class

#### Examples

##### Basic Usage

```puppet
class { '::st2':
  chatops_hubot_name => '"@RosieRobot"',
  chatops_api_key    => '"xxxxyyyyy123abc"',
  chatops_adapter    => {
    hubot-adapter => {
      package => 'hubot-rocketchat',
      source  => 'git+ssh://git@git.company.com:npm/hubot-rocketchat#master',
    },
  },
  chatops_adapter_conf => {
    HUBOT_ADAPTER        => 'rocketchat',
    ROCKETCHAT_URL       => 'https://chat.company.com',
    ROCKETCHAT_ROOM      => 'stackstorm',
    LISTEN_ON_ALL_PUBLIC => 'true',
    ROCKETCHAT_USER      => 'st2',
    ROCKETCHAT_PASSWORD  => 'secret123',
    ROCKETCHAT_AUTH      => 'password',
    RESPOND_TO_DM        => 'true',
  },
}
```

#### Parameters

The following parameters are available in the `st2::profile::chatops` class.

##### `version`

Data type: `Any`

Version of the st2chatops package to install

Default value: $::st2::version

##### `hubot_log_level`

Data type: `Any`

Hubot log level

Default value: $::st2::chatops_hubot_log_level

##### `hubot_express_port`

Data type: `Any`

Express port hubot listens to

Default value: $::st2::chatops_hubot_express_port

##### `tls_cert_reject_unauthorized`

Data type: `Any`

Set to 1 when using self signed certs

Default value: $::st2::chatops_tls_cert_reject_unauthorized

##### `hubot_name`

Data type: `Any`

Name of the bot in chat. Should be properly quoted if it has special characters,
example: '"MyBot!"'

Default value: $::st2::chatops_hubot_name

##### `hubot_alias`

Data type: `Any`

Character to trigger the bot at the beginning of a message. Must be properly
quoted of it's a special character, example: "'!'"

Default value: $::st2::chatops_hubot_alias

##### `npm_packages`

Data type: `Any`

NodeJS packages to be installed (usually a hubot adapter)

Default value: $::st2::chatops_adapter

##### `adapter_config`

Data type: `Any`

Configuration parameters for Hubot adapter (hash)

Default value: $::st2::chatops_adapter_conf

##### `api_key`

Data type: `Any`

API key generated by <code>st2 apikey create</code> that hubot will use to post data back
to StackStorm.

Default value: $::st2::chatops_api_key

##### `st2_hostname`

Data type: `Any`

Hostname of the StackStorm instance that chatops will connect to for API and Auth.
If unspecified it will use the default in <code>/opt/stackstorm/chatops/st2chatops.env</code>

Default value: $::st2::chatops_st2_hostname

##### `web_url`

Data type: `Any`

Public URL of StackStorm instance. Used by chatops to offer links to execution details in a chat.
If unspecified it will use the default in <code>/opt/stackstorm/chatops/st2chatops.env</code>

Default value: $::st2::chatops_web_url

##### `api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: $::st2::chatops_api_url

##### `auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: $::st2::chatops_auth_url

##### `auth_username`

Data type: `Any`

StackStorm auth Username for ChatOps to communicate back with StackStorm.
Used if +api_key+ is not specified (optional)

Default value: $::st2::cli_username

##### `auth_password`

Data type: `Any`

StackStorm auth Password for ChatOps to communicate back with StackStorm.
Used if +api_key+ is not specified (optional)

Default value: $::st2::cli_password

### st2::profile::client

Profile to install, configure and manage all client libraries for st2

#### Examples

##### Basic Usage

```puppet
include st2::profile::client
```

#### Parameters

The following parameters are available in the `st2::profile::client` class.

##### `auth`

Data type: `Any`

Is auth enabled or not.

Default value: $::st2::auth

##### `api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: $::st2::cli_api_url

##### `auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: $::st2::cli_auth_url

##### `base_url`

Data type: `Any`

Base URL for other StackStorm services

Default value: $::st2::cli_base_url

##### `username`

Data type: `Any`

Username for auth on the CLI

Default value: $::st2::cli_username

##### `password`

Data type: `Any`

Password for auth on the CLI

Default value: $::st2::cli_password

##### `api_version`

Data type: `Any`

Version of the StackStorm API

Default value: $::st2::cli_api_version

##### `cacert`

Data type: `Any`

Path to the SSL CA certficate for the StackStorm services

Default value: $::st2::cli_cacert

##### `debug`

Data type: `Any`

Enable debug mode

Default value: $::st2::cli_debug

##### `cache_token`

Data type: `Any`

Enable cacheing authentication tokens until they expire

Default value: $::st2::cli_cache_token

##### `silence_ssl_warnings`

Data type: `Any`

Enable silencing SSL warnings for self-signed certs

Default value: $::st2::cli_silence_ssl_warnings

### st2::profile::facter

Setup custom fact locations

#### Examples

##### Basic Usage

```puppet
include st2::profile::facter
```

### st2::profile::fullinstall

Components:
 * RabbitMQ
 * Python
 * MongoDB
 * NodeJS
 * nginx
 * PostgreSQL (required by Mistral)
 * Mistral

#### Examples

##### Basic Usage

```puppet
include ::st2::profile::fullinstall
```

##### Customizing parameters

```puppet
# Customizations are done via the main ::st2 class
class { '::st2':
  # ... assign custom parameters
}

include ::st2::profile::fullinstall
```

### st2::profile::mistral

This class installs OpenStack Mistral, a workflow engine that integrates with StackStorm.

#### Examples

##### Basic Usage

```puppet
include ::st2::profile::mistral
```

##### External database

```puppet
class { '::st2::profile::mistral':
  db_host     => 'postgres.domain.tld',
  db_username => 'mistral',
  db_password => 'xyz123',
}
```

##### External RabbitMQ

```puppet
class { '::st2::profile::mistral':
  rabbitmq_hostname => 'rabbitmq.domain.tld',
  rabbitmq_username => 'mistral',
  rabbitmq_password => 'xyz123',
}
```

#### Parameters

The following parameters are available in the `st2::profile::mistral` class.

##### `version`

Data type: `Any`

Version of the st2mistral package to install

Default value: $::st2::version

##### `db_host`

Data type: `Any`

Server hosting Mistral Postgres DB

Default value: $::st2::mistral_db_host

##### `db_name`

Data type: `Any`

Name of the Mistral Postgres database

Default value: $::st2::mistral_db_name

##### `db_username`

Data type: `Any`

Mistral user for authenticating with PostgreSQL

Default value: $::st2::mistral_db_username

##### `db_password`

Data type: `Any`

Mistral password for authenticating with PostgreSQL

Default value: $::st2::mistral_db_password

##### `rabbitmq_username`

Data type: `Any`

Username for authenticating with RabbitMQ

Default value: $::st2::rabbitmq_username

##### `rabbitmq_password`

Data type: `Any`

Password for authenticating with RabbitMQ

Default value: $::st2::rabbitmq_password

##### `rabbitmq_hostname`

Data type: `Any`

Hostname/IP of the RabbitMQ server

Default value: $::st2::rabbitmq_hostname

##### `rabbitmq_port`

Data type: `Any`

Port for connecting to RabbitMQ

Default value: $::st2::rabbitmq_port

##### `rabbitmq_vhost`

Data type: `Any`

RabbitMQ virtual host for Mistral

Default value: $::st2::rabbitmq_vhost

### st2::profile::mongodb

StackStorm compatable installation of MongoDB and dependencies.

#### Examples

##### Basic Usage

```puppet
include ::st2::profile::mongodb
```

##### Customize (done via ::st2)

```puppet
class { '::st2':
  db_name     => 'stackstormdb',
  db_username => 'abc',
  db_password => 'xyz123',
  db_port     => 12345,
}
include ::st2::profile::mongodb
```

#### Parameters

The following parameters are available in the `st2::profile::mongodb` class.

##### `db_name`

Data type: `Any`

Name of the StackStorm database

Default value: $::st2::db_name

##### `db_username`

Data type: `Any`

Username to connect to db with

Default value: $::st2::db_username

##### `db_password`

Data type: `Any`

Password for 'admin' and 'stackstorm' users in MongDB. If 'undef' then use $cli_password

Default value: $::st2::db_password

##### `db_port`

Data type: `Any`

Port for db server for st2 to talk to

Default value: $::st2::db_port

##### `db_bind_ips`

Data type: `Any`

Array of bind IP addresses for MongoDB to listen on

Default value: $::st2::db_bind_ips

##### `version`

Data type: `Any`

Version of MongoDB to install. If not provided it will be auto-calcuated based on $st2::version.

Default value: $::st2::mongodb_version

##### `manage_repo`

Data type: `Any`

Set this to +false+ when you have your own repositories for mongodb

Default value: $::st2::mongodb_manage_repo

##### `auth`

Data type: `Any`

Boolean determining if auth should be enabled for MongoDB.

Default value: $::st2::mongodb_auth

### st2::profile::nginx

StackStorm compatible installation of nginx and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::nginx
```

#### Parameters

The following parameters are available in the `st2::profile::nginx` class.

##### `manage_repo`

Data type: `Any`

Set this to false when you have your own repository for nginx

Default value: $::st2::nginx_manage_repo

### st2::profile::nodejs

This class is needed for StackStorm ChatOps +st2::profile::chatops::.
Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>NodeJS</code> installation on a single node.

#### Examples

##### Basic Usage

```puppet
include st2::profile::nodejs
```

##### Custom Parameters

```puppet
class { 'st2::profile::nodejs':
}
```

#### Parameters

The following parameters are available in the `st2::profile::nodejs` class.

##### `manage_repo`

Data type: `Any`

Set this to false when you have your own repositories for NodeJS.

Default value: $::st2::nodejs_manage_repo

##### `version`

Data type: `Any`

Version of NodeJS to install. If not provided it will be auto-calcuated based on $::st2::version

Default value: $::st2::nodejs_version

### st2::profile::postgresql

st2 compatable installation of PostgreSQL and dependencies for use with StackStorm and Mistral.

#### Examples

##### Basic usage

```puppet
include ::st2::profile::postgresql
```

##### Customizing parameters

```puppet
class { '::st2::profile::postgresql':
  db_bind_ips => '0.0.0.0',
}
```

#### Parameters

The following parameters are available in the `st2::profile::postgresql` class.

##### `bind_ips`

Data type: `Any`

String of IPs (csv) that the Postgres database will accept connections on.

Default value: $::st2::mistral_db_bind_ips

### st2::profile::python

StackStorm compatable installation of Python and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::python
```

### st2::profile::rabbitmq

StackStorm compatable installation of RabbitMQ and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::rabbitmq
```

##### Authentication enabled (configured vi ::st2)

```puppet
class { '::st2':
  rabbitmq_username => 'rabbitst2',
  rabbitmq_password => 'secret123',
}
include st2::profile::rabbitmq
```

#### Parameters

The following parameters are available in the `st2::profile::rabbitmq` class.

##### `username`

Data type: `Any`

User to create within RabbitMQ for authentication.

Default value: $::st2::rabbitmq_username

##### `password`

Data type: `Any`

Password of +username+ for RabbitMQ authentication.

Default value: $::st2::rabbitmq_password

##### `port`

Data type: `Any`

Port to bind to for the RabbitMQ server

Default value: $::st2::rabbitmq_port

##### `bind_ip`

Data type: `Any`

IP address to bind to for the RabbitMQ server

Default value: $::st2::rabbitmq_bind_ip

##### `vhost`

Data type: `Any`

RabbitMQ virtual host to create for StackStorm

Default value: $::st2::rabbitmq_vhost

### st2::profile::repos

Manages the installation of st2 required repos for installing the StackStorm packages.

#### Examples

##### Basic usage

```puppet
include ::st2::profile::repos
```

##### Installing from unstable

```puppet
class { '::st2::profile::repos':
  repository => 'unstable',
}
```

#### Parameters

The following parameters are available in the `st2::profile::repos` class.

##### `repository`

Data type: `Any`

Release repository to enable. Options: 'stable', 'unstable'.

Default value: $::st2::repository

##### `package_type`

Data type: `Any`

Type of package management system used for repo. Options: 'rpm', 'deb'

Default value: $::st2::params::package_type

### st2::profile::selinux

Configure SELinux so that StackStorm services run properly

#### Examples

##### Basic Usage

```puppet
include st2::profile::selinux
```

### st2::profile::server

Profile to install, configure and manage all server components for st2

#### Examples

##### Basic usage

```puppet
include st2::profile::server
```

#### Parameters

The following parameters are available in the `st2::profile::server` class.

##### `version`

Data type: `Any`

Version of StackStorm to install

Default value: $::st2::version

##### `conf_dir`

Data type: `Any`

The directory where st2 configs are stored

Default value: $::st2::conf_dir

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `auth`

Data type: `Any`

Toggle Auth

Default value: $::st2::auth

##### `actionrunner_workers`

Data type: `Any`

Set the number of actionrunner processes to start

Default value: $::st2::actionrunner_workers

##### `st2api_listen_ip`

Data type: `Any`

Listen IP for st2api process

Default value: '0.0.0.0'

##### `st2api_listen_port`

Data type: `Any`

Listen port for st2api process

Default value: '9101'

##### `st2auth_listen_ip`

Data type: `Any`

Listen IP for st2auth process

Default value: '0.0.0.0'

##### `st2auth_listen_port`

Data type: `Any`

Listen port for st2auth process

Default value: '9100'

##### `syslog`

Data type: `Any`

Routes all log messages to syslog

Default value: $::st2::syslog

##### `syslog_host`

Data type: `Any`

Syslog host.

Default value: $::st2::syslog_host

##### `syslog_protocol`

Data type: `Any`

Syslog protocol.

Default value: $::st2::syslog_protocol

##### `syslog_port`

Data type: `Any`

Syslog port.

Default value: $::st2::syslog_port

##### `syslog_facility`

Data type: `Any`

Syslog facility.

Default value: $::st2::syslog_facility

##### `ssh_key_location`

Data type: `Any`

Location on filesystem of Admin SSH key for remote runner

Default value: $::st2::ssh_key_location

##### `db_username`

Data type: `Any`

Username to connect to MongoDB with (default: 'stackstorm')

Default value: $::st2::db_username

##### `db_password`

Data type: `Any`

Password for 'stackstorm' user in MongDB.

Default value: $::st2::db_password

##### `index_url`

Data type: `Any`

Url to the StackStorm Exchange index file. (default undef)

Default value: $::st2::index_url

##### `ng_init`

Data type: `Any`



Default value: $::st2::ng_init

##### `rabbitmq_username`

Data type: `Any`



Default value: $::st2::rabbitmq_username

##### `rabbitmq_password`

Data type: `Any`



Default value: $::st2::rabbitmq_password

##### `rabbitmq_hostname`

Data type: `Any`



Default value: $::st2::rabbitmq_hostname

##### `rabbitmq_port`

Data type: `Any`



Default value: $::st2::rabbitmq_port

##### `rabbitmq_vhost`

Data type: `Any`



Default value: $::st2::rabbitmq_vhost

### st2::profile::web

Profile to install, configure and manage StackStorm web UI (st2web).

#### Examples

##### Basic Usage

```puppet
include ::st2::profile::web'
```

#### Parameters

The following parameters are available in the `st2::profile::web` class.

##### `ssl_dir`

Data type: `Any`

Directory where st2web will look for its SSL info.
(default: /etc/ssl/st2)

Default value: $::st2::ssl_dir

##### `ssl_cert`

Data type: `Any`

Path to the file where the StackStorm SSL cert will
be generated. (default: /etc/ssl/st2/st2.crt)

Default value: $::st2::ssl_cert

##### `ssl_key`

Data type: `Any`

Path to the file where the StackStorm SSL key will
be generated. (default: /etc/ssl/st2/st2.key)

Default value: $::st2::ssl_key

##### `version`

Data type: `Any`

Version of StackStorm WebUI to install

Default value: $::st2::version

### st2::scheduler

Normally this class is instantiated by <code>st2::profile::fullinstall</code>.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2scheduler</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample#L251-L259

#### Examples

##### Basic usage

```puppet
include ::st2::scheduler
```

##### Customizing parameters

```puppet
class { '::st2::scheduler':
  sleep_interval => 60,
  gc_interval    => 120,
}
```

#### Parameters

The following parameters are available in the `st2::scheduler` class.

##### `sleep_interval`

Data type: `Any`

How long (in seconds) to sleep between each action scheduler main loop run interval.

Default value: $::st2::scheduler_sleep_interval

##### `gc_interval`

Data type: `Any`

How often (in seconds) to look for zombie execution requests before rescheduling them.

Default value: $::st2::scheduler_gc_interval

##### `pool_size`

Data type: `Any`

The size of the pool used by the scheduler for scheduling executions.

Default value: $::st2::scheduler_pool_size

### st2::server::datastore_keys

Generates and manages crypto keys for use with the StackStorm datastore

#### Examples

##### Basic Usage

```puppet
include ::st2::server::datastore_keys
```

##### Custom key path

```puppet
class { '::st2::server::datastore_keys':
  keys_dir => '/path/to/custom/keys',
  key_path => '/path/to/custom/keys/datastore_key.json.',
}
```

#### Parameters

The following parameters are available in the `st2::server::datastore_keys` class.

##### `conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: $::st2::conf_file

##### `keys_dir`

Data type: `Any`

The directory where the datastore keys will be stored

Default value: $::st2::datastore_keys_dir

##### `key_path`

Data type: `Any`

Path to the key file

Default value: $::st2::datastore_key_path

### st2::stanley

Installs the default admin user for st2 (stanley).

* **Note** Will install auto-generate SSH keys of none are provided.

#### Examples

##### Basic Usage

```puppet
include ::st2::stanley
```

##### Custom SSH keys

```puppet
class { '::st2::stanley':
  ssh_key_type => 'ssh-rsa',
  ssh_public_key => 'AAAAAWESOMEKEY==',
  ssh_private_key => '----- BEGIN RSA PRIVATE KEY -----\nDEADBEEF\n----- END RSA PRIVATE KEY -----',
}
```

#### Parameters

The following parameters are available in the `st2::stanley` class.

##### `username`

Data type: `Any`

Name of the stanley user

Default value: 'stanley'

##### `ssh_public_key`

Data type: `Any`

SSH Public Key without leading key-type and end email

Default value: `undef`

##### `ssh_key_type`

Data type: `Any`

Type of SSH Key (ssh-dsa/ssh-rsa)

Default value: `undef`

##### `ssh_private_key`

Data type: `Any`

Private key

Default value: `undef`

##### `client`

Data type: `Any`

Allow incoming connections from the defined user

Default value: `true`

##### `server`

Data type: `Any`

Server where connection requests originate (usually st2 server)

Default value: `true`

### st2::timersengine

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2timersengine</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample#L337-L343

#### Examples

##### Basic usage

```puppet
include ::st2::timersengine
```

##### Customizing parameters

```puppet
class { '::st2::timersengine':
  enabled  => true,
  timezone => 'America/Los_Angeles',
}
```

#### Parameters

The following parameters are available in the `st2::timersengine` class.

##### `enabled`

Data type: `Any`

Specify to enable timer service.

Default value: $::st2::timersengine_enabled

##### `timezone`

Data type: `Any`

Timezone pertaining to the location where st2 is run.

Default value: $::st2::timersengine_timezone

### st2::workflowengine

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2workflowengine</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample

#### Examples

##### Basic usage

```puppet
include ::st2::workflowengine
```

## Defined types

### st2::auth_user

Creates and manages StackStorm application users (flat_file auth only)

#### Examples

##### Basic usage

```puppet
st2::auth_user { 'st2admin':
  password => 'neato!',
}
```

#### Parameters

The following parameters are available in the `st2::auth_user` defined type.

##### `name`

Name of the user

##### `ensure`

Data type: `Any`

Ensure user exists or not

Default value: present

##### `password`

Data type: `Any`

User's password

Default value: `undef`

### st2::client::settings

Generates a configuration file for the st2 CLI (st2client)

#### Examples

##### Basic usage

```puppet
::st2::client::settings { 'john':
  username => 'st2_john',
  password => 'xyz123',
}
```

#### Parameters

The following parameters are available in the `st2::client::settings` defined type.

##### `name`

OS-level username. Used to determine where the config file will be placed.

##### `user`

Data type: `Any`

See name

Default value: $name

##### `homedir`

Data type: `Any`

Path to home directory of the user.

Default value: "/home/${name}"

##### `auth`

Data type: `Any`

Is auth enabled or not.

Default value: $::st2::auth

##### `api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: $::st2::cli_api_url

##### `auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: $::st2::cli_auth_url

##### `base_url`

Data type: `Any`

Base URL for other StackStorm services

Default value: $::st2::cli_base_url

##### `username`

Data type: `Any`

Username for auth on the CLI

Default value: $::st2::cli_username

##### `password`

Data type: `Any`

Password for auth on the CLI

Default value: $::st2::cli_password

##### `disable_credentials`

Data type: `Any`

Prevents credentials (username, password) from being written to the config file

Default value: `false`

##### `api_version`

Data type: `Any`

Version of the StackStorm API

Default value: $::st2::cli_api_version

##### `cacert`

Data type: `Any`

Path to the SSL CA certficate for the StackStorm services

Default value: $::st2::cli_cacert

##### `debug`

Data type: `Any`

Enable debug mode

Default value: $::st2::cli_debug

##### `cache_token`

Data type: `Any`

Enable cacheing authentication tokens until they expire

Default value: $::st2::cli_cache_token

##### `silence_ssl_warnings`

Data type: `Any`

Enable silencing SSL warnings for self-signed certs

Default value: $::st2::cli_silence_ssl_warnings

### st2::kv

Sets a value to the StackStorm Key/Value Store

#### Examples

##### Basic usage

```puppet
st2::kv { 'install_uuid':
  value => $_uuid,
}
```

#### Parameters

The following parameters are available in the `st2::kv` defined type.

##### `key`

Data type: `Any`

Key to set

Default value: $name

##### `value`

Data type: `Any`

Value of key

##### `ensure`

Data type: `Any`



Default value: present

### st2::pack

Manages a StackStorm Pack

#### Examples

##### Basic Usage

```puppet
st2::pack { 'puppet': }
```

##### Install from a custom URL

```puppet
st2::pack { 'custom':
  repo_url => 'http://github.com/myorg/stackstorm-custom.git',
}
```

#### Parameters

The following parameters are available in the `st2::pack` defined type.

##### `pack`

Data type: `Any`

Name of the pack to install.

Default value: $name

##### `repo_url`

Data type: `Any`

URL of the package to install when not installing from the exchange.

Default value: `undef`

##### `config`

Data type: `Any`

Hash that will be translated into YAML in the pack's config file after installation.

Default value: `undef`

##### `ensure`

Data type: `Any`



Default value: present

### st2::rbac

This defined type creates RBAC resources for users

* **Note** This is an enterprise feature, and requires a license to be used.

#### Examples

##### 

```puppet
st2::rbac { 'admin':
  description => "Administrative user",
  roles       => [
    'observer',
    'my_test_role',
  ],
}
```

#### Parameters

The following parameters are available in the `st2::rbac` defined type.

##### `ensure`

Data type: `Any`



Default value: 'present'

##### `user`

Data type: `Any`



Default value: $name

##### `description`

Data type: `Any`



Default value: 'Created and managed by Puppet'

##### `roles`

Data type: `Any`



Default value: []

### st2::user

Creates an system (OS level) user for use with StackStorm

#### Examples

##### Custom SSH keys

```puppet
st2::user { 'stanley':
  ssh_key_type => 'ssh-rsa',
  ssh_public_key => 'AAAAAWESOMEKEY==',
  ssh_private_key => '----- BEGIN RSA PRIVATE KEY -----\nDEADBEEF\n----- END RSA PRIVATE KEY -----',
}
```

#### Parameters

The following parameters are available in the `st2::user` defined type.

##### `client`

Data type: `Any`

Allow incoming connections from the defined user

Default value: `true`

##### `server`

Data type: `Any`

Server where connection requests originate (usually st2 server)

Default value: `false`

##### `create_sudo_entry`

Data type: `Any`

Manage the sudoers entry (default: false)

Default value: `false`

##### `ssh_public_key`

Data type: `Any`

SSH Public Key without leading key-type and end email.

Default value: `undef`

##### `ssh_key_type`

Data type: `Any`

Type of SSH Key (ssh-dsa/ssh-rsa)

Default value: `undef`

##### `ssh_private_key`

Data type: `Any`

SSH Private key. If not specified, then one will be generated.

Default value: `undef`

##### `groups`

Data type: `Any`

List of groups (OS level) that this user should be a member of

Default value: `undef`

##### `ssh_dir`

Data type: `Any`

Directory where SSH keys will be stored

Default value: "/home/${name}/.ssh"

## Resource types

### st2_pack

Manage st2 packs

#### Properties

The following properties are available in the `st2_pack` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

#### Parameters

The following parameters are available in the `st2_pack` type.

##### `name`

namevar

Name of the pack.

##### `user`

St2 cli user

##### `password`

St2 cli password

##### `source`

Git URL for st2 pack

## Functions

### st2::urlencode

Type: Ruby 4.x API

URL encodes a string

#### `st2::urlencode(String $url)`

URL encodes a string

Returns: `String` URL encoded data

##### `url`

Data type: `String`

Raw URL data to encode

### st2::version_ge

Type: Puppet Language

Determines if the StackStorm version installed on the system <code>$facts['st2_version']</code>
or the version requested by the user <code>$::st2::version</code> is greater than or equal
to <code>$version</code>.

This is used to determine if this Puppet module should enable features for managing
specific versions of StackStorm. Older versions of StackStorm will not have new features
and we don't want this module to try and manage them if they're not present on the system.

Users who have old version of StackStorm installed may have <code>$::st2::version = 'present'</code>
or <code>$::st2::version = 'installed'</code>. In this case, we don't want to assume the user
has a new version of StackStorm or wants to upgrade. Instead, we should assume that
this the installed version of StackStorm is the version we should be using to compare.

#### `st2::version_ge(String $version)`

Determines if the StackStorm version installed on the system <code>$facts['st2_version']</code>
or the version requested by the user <code>$::st2::version</code> is greater than or equal
to <code>$version</code>.

This is used to determine if this Puppet module should enable features for managing
specific versions of StackStorm. Older versions of StackStorm will not have new features
and we don't want this module to try and manage them if they're not present on the system.

Users who have old version of StackStorm installed may have <code>$::st2::version = 'present'</code>
or <code>$::st2::version = 'installed'</code>. In this case, we don't want to assume the user
has a new version of StackStorm or wants to upgrade. Instead, we should assume that
this the installed version of StackStorm is the version we should be using to compare.

Returns: `Boolean` True if the StackStorm version on the system or $::st2::version is
>= to the +version+ parameter.

##### `version`

Data type: `String`

Version string to compare against. This should be in SemVer format

